==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/ar.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'ar', {
	acccessKey: 'مفاتيح الإختصار',
	advanced: 'متقدم',
	advisoryContentType: 'نوع التقرير',
	advisoryTitle: 'عنوان التقرير',
	anchor: {
		toolbar: 'إشارة مرجعية',
		menu: 'تحرير الإشارة المرجعية',
		title: 'خصائص الإشارة المرجعية',
		name: 'اسم الإشارة المرجعية',
		errorName: 'الرجاء كتابة اسم الإشارة المرجعية',
		remove: 'إزالة الإشارة المرجعية'
	},
	anchorId: 'حسب رقم العنصر',
	anchorName: 'حسب إسم الإشارة المرجعية',
	charset: 'ترميز المادة المطلوبة',
	cssClasses: 'فئات التنسيق',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'البريد الإلكتروني',
	emailBody: 'محتوى الرسالة',
	emailSubject: 'موضوع الرسالة',
	id: 'هوية',
	info: 'معلومات الرابط',
	langCode: 'رمز اللغة',
	langDir: 'إتجاه نص اللغة',
	langDirLTR: 'اليسار لليمين (LTR)',
	langDirRTL: 'اليمين لليسار (RTL)',
	menu: 'تحرير الرابط',
	name: 'إسم',
	noAnchors: '(لا توجد علامات مرجعية في هذا المستند)',
	noEmail: 'الرجاء كتابة الريد الإلكتروني',
	noUrl: 'الرجاء كتابة رابط الموقع',
	other: '<أخرى>',
	popupDependent: 'تابع (Netscape)',
	popupFeatures: 'خصائص النافذة المنبثقة',
	popupFullScreen: 'ملئ الشاشة (IE)',
	popupLeft: 'التمركز لليسار',
	popupLocationBar: 'شريط العنوان',
	popupMenuBar: 'القوائم الرئيسية',
	popupResizable: 'قابلة التشكيل',
	popupScrollBars: 'أشرطة التمرير',
	popupStatusBar: 'شريط الحالة',
	popupToolbar: 'شريط الأدوات',
	popupTop: 'التمركز للأعلى',
	rel: 'العلاقة',
	selectAnchor: 'اختر علامة مرجعية',
	styles: 'نمط',
	tabIndex: 'الترتيب',
	target: 'هدف الرابط',
	targetFrame: '<إطار>',
	targetFrameName: 'اسم الإطار المستهدف',
	targetPopup: '<نافذة منبثقة>',
	targetPopupName: 'اسم النافذة المنبثقة',
	title: 'رابط',
	toAnchor: 'مكان في هذا المستند',
	toEmail: 'بريد إلكتروني',
	toUrl: 'الرابط',
	toolbar: 'رابط',
	type: 'نوع الربط',
	unlink: 'إزالة رابط',
	upload: 'رفع'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/ar.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'ar', {
	acccessKey: 'مفاتيح الإختصار',
	advanced: 'متقدم',
	advisoryContentType: 'نوع التقرير',
	advisoryTitle: 'عنوان التقرير',
	anchor: {
		toolbar: 'إشارة مرجعية',
		menu: 'تحرير الإشارة المرجعية',
		title: 'خصائص الإشارة المرجعية',
		name: 'اسم الإشارة المرجعية',
		errorName: 'الرجاء كتابة اسم الإشارة المرجعية',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'إزالة الإشارة المرجعية'
	},
	anchorId: 'حسب رقم العنصر',
	anchorName: 'حسب إسم الإشارة المرجعية',
	charset: 'ترميز المادة المطلوبة',
	cssClasses: 'فئات التنسيق',
	download: 'فرض التحميل',
	displayText: 'نص العرض',
	emailAddress: 'البريد الإلكتروني',
	emailBody: 'محتوى الرسالة',
	emailSubject: 'موضوع الرسالة',
	id: 'هوية',
	info: 'معلومات الرابط',
	langCode: 'رمز اللغة',
	langDir: 'إتجاه نص اللغة',
	langDirLTR: 'اليسار لليمين (LTR)',
	langDirRTL: 'اليمين لليسار (RTL)',
	menu: 'تحرير الرابط',
	name: 'إسم',
	noAnchors: '(لا توجد علامات مرجعية في هذا المستند)',
	noEmail: 'الرجاء كتابة الريد الإلكتروني',
	noUrl: 'الرجاء كتابة رابط الموقع',
	noTel: 'Please type the phone number', // MISSING
	other: '<أخرى>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'تابع (Netscape)',
	popupFeatures: 'خصائص النافذة المنبثقة',
	popupFullScreen: 'ملئ الشاشة (IE)',
	popupLeft: 'التمركز لليسار',
	popupLocationBar: 'شريط العنوان',
	popupMenuBar: 'القوائم الرئيسية',
	popupResizable: 'قابلة التشكيل',
	popupScrollBars: 'أشرطة التمرير',
	popupStatusBar: 'شريط الحالة',
	popupToolbar: 'شريط الأدوات',
	popupTop: 'التمركز للأعلى',
	rel: 'العلاقة',
	selectAnchor: 'اختر علامة مرجعية',
	styles: 'نمط',
	tabIndex: 'الترتيب',
	target: 'هدف الرابط',
	targetFrame: '<إطار>',
	targetFrameName: 'اسم الإطار المستهدف',
	targetPopup: '<نافذة منبثقة>',
	targetPopupName: 'اسم النافذة المنبثقة',
	title: 'رابط',
	toAnchor: 'مكان في هذا المستند',
	toEmail: 'بريد إلكتروني',
	toUrl: 'الرابط',
	toPhone: 'Phone', // MISSING
	toolbar: 'رابط',
	type: 'نوع الربط',
	unlink: 'إزالة رابط',
	upload: 'رفع'
} );
